@@ -13,3 +13,7 @@ PhonePanel::PhonePanel(QObject *parent, const KPluginMetaData &data, const QVari
 }
 
 PhonePanel::~PhonePanel() = default;
+
+K_PLUGIN_CLASS(PhonePanel)
+
+#include "phonepanel.moc"
